#region MigraDoc - Creating Documents on the Fly
//
// Authors:
//   PDFsharp Team (mailto:PDFsharpSupport@pdfsharp.de)
//
// Copyright (c) 2001-2009 empira Software GmbH, Cologne (Germany)
//
// http://www.pdfsharp.com
// http://www.migradoc.com
// http://sourceforge.net/projects/pdfsharp
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
#endregion

using System;
using System.Diagnostics;
using System.Text;
using MigraDoc.DocumentObjectModel;
using HelloMigraDoc;
using MigraDoc.DocumentObjectModel.Shapes;
using MigraDoc.DocumentObjectModel.Tables;



namespace DocumentViewer
{
  sealed class SampleDocuments
  {
       
        private static TextFrame field_1,field_2,field_3,field_4;
        //static Table table;
        readonly static Color TableBorder = new Color(0, 0, 0);
        readonly static Color TableBlue = new Color(235, 240, 249);
        readonly static Color TableGray = new Color(242, 242, 242);





        /// <summary>
        /// Creates the initial sample document.
        /// </summary>
        public static Document CreateSample1()
        {

            // variables
            Table table,table2,table3;

            // Create a new MigraDoc document
            String tPdfFont = "Arial";
            Document document = new Document();
            MigraDoc.DocumentObjectModel.Style style = document.Styles["Normal"];
            style.Font.Name = tPdfFont;

            // Add a section to the document
            Section section = document.AddSection();
            section.PageSetup.LeftMargin = "1pt";
            section.PageSetup.TopMargin = "1pt";


            #region 
            // Add a paragraph to the section
            Paragraph paragraph = section.AddParagraph();
            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Margin;
            field_1.Height = "20pt";
            field_1.Width = "160pt";
            field_1.Left = "30pt";
            field_1.Top = "51pt";
            paragraph = field_1.AddParagraph(" 1-5,7-24,26-28,50,58,60-63, 66  ");
            paragraph.AddLineBreak();
            paragraph.AddText(" 25,26,28,29-49,51,52,56,57,59,64,65  .  ");
            paragraph.AddText(" 6,53  ");
            paragraph.Format.Font.Size = 4.5;
            paragraph.Format.LineSpacingRule = LineSpacingRule.Exactly;
            paragraph.Format.LineSpacing = 5.5;

            //            
            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Margin;
            //this.field_1.RelativeHorizontal = RelativeHorizontal.Margin;
            field_1.Height = "10pt";
            field_1.Width = "125pt";
            field_1.Left = "255pt";
            field_1.Top = "48pt";
            paragraph = field_1.AddParagraph("        ");
            paragraph.Format.Font.Size = 12;
            paragraph.Format.Font.Bold = true;

            //  58
            SampleDocuments.field_1 = section.AddTextFrame();
            table = SampleDocuments.field_1.AddTable();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "73pt";
            SampleDocuments.field_1.Left = "28pt";
            field_1 = section.AddTextFrame();
            field_1.Top = "76pt";
            field_1.Left = "28pt";
            field_1.RelativeVertical = RelativeVertical.Page;
            paragraph = field_1.AddParagraph("58   ");
            paragraph.Format.Font.Size = 5;
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            table.Rows.Height = "21pt";
            table.Columns.Width = "270pt";
            Column column = table.AddColumn();
            column.Format.Alignment = ParagraphAlignment.Right;
            Row row = table.AddRow();
            Cell cell = row.Cells[0];
            paragraph = cell.AddParagraph("        7880");
            paragraph.Format.Font.Size = 18;
            paragraph.Format.Font.Bold = true;
            #endregion

            #region 59-66
            //fields  59-66
            field_2 = section.AddTextFrame();
            // field_2.RelativeVertical = RelativeVertical.Margin;
            field_2.RelativeVertical = RelativeVertical.Page;
            field_2.Top = "73pt";
            field_2.Left = "298pt";
            table2 = field_2.AddTable();
            table2.Borders.Width = "1 pt";
            table2.Borders.Left.Visible = false;
            table2.Borders.Color = TableBorder;
            Column column2 = table2.AddColumn();
            column2 = table2.AddColumn();
            column2 = table2.AddColumn();
            column2 = table2.AddColumn();
            Row row2 = table2.AddRow();
            Row row3 = table2.AddRow();
            table2.Rows.HeightRule = RowHeightRule.Exactly;
            table2.Rows.Height = "10.25pt";
            table2.Columns.Width = "62pt";
            cell = row2.Cells[0];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("59|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            cell = row2.Cells[1];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("60|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            cell = row2.Cells[2];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("61|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            cell = row2.Cells[3];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("62|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            cell = row3.Cells[0];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("63|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            cell = row3.Cells[1];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("64|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            cell = row3.Cells[2];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("65|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            cell = row3.Cells[3];
            paragraph = cell.AddParagraph();
            paragraph.AddFormattedText("66|||||");
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph.Format.Font.Size = 5;
            #endregion

            #region   1-3 
            // 1-3
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "95pt";
            SampleDocuments.field_1.Left = "28pt";
            table = SampleDocuments.field_1.AddTable();
            table.Borders.Width = "1pt";
            table.Borders.Color = TableBorder;
            column = table.AddColumn(Unit.FromPoint(197));
            column = table.AddColumn(Unit.FromPoint(73));
            row = table.AddRow();
            row.TopPadding = "0pt";
            row.Cells[0].Borders.Right.Visible = false;
            SampleDocuments.field_1 = row.Cells[1].AddTextFrame();
            table2 = SampleDocuments.field_1.AddTable();
            table2.Borders.Width = "1 pt";
            table2.BottomPadding = 0;
            table2.Borders.Color = TableBorder;
            table2.Borders.Style = BorderStyle.DashDotDot;
            column = table2.AddColumn();
            column.RightPadding = "2pt";
            column.LeftPadding = "2pt";
            row = table2.AddRow();
            row.Cells[0].Borders.Right.Visible = false;
            row.Cells[0].Borders.Top.Visible = false;
            row.Cells[0].Borders.Style = BorderStyle.Single;
            //field 2 data data 4 digit code
            paragraph = row.Cells[0].AddParagraph("1234");
            paragraph.Format.Font.Size = 12;
            paragraph.Format.Font.Bold = true;
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            row = table2.AddRow();
            row.Cells[0].Borders.Right.Visible = false;
            //field e-mail
            row = table2.AddRow();
            paragraph = row.Cells[0].AddParagraph("sender@domain.com");
            paragraph.Format.Font.Size = 6;
            row.Cells[0].VerticalAlignment = VerticalAlignment.Bottom;
            row.Cells[0].Borders.Visible = false;
            row = table2.AddRow();
            row.Cells[0].Borders.Visible = false;
            table2.Rows.HeightRule = RowHeightRule.Exactly;
            table2.Rows.Height = "15pt";
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "115pt";
            SampleDocuments.field_1.Left = "224pt";
            paragraph = SampleDocuments.field_1.AddParagraph("3");
            paragraph.Format.Font.Size = 5;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "100pt";
            SampleDocuments.field_1.Left = "224pt";
            paragraph = SampleDocuments.field_1.AddParagraph("2");
            paragraph.Format.Font.Size = 5;
            // email field
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "132pt";
            SampleDocuments.field_1.Left = "222pt";
            paragraph = SampleDocuments.field_1.AddParagraph(".");
            paragraph.Format.Font.Size = 5;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "145pt";
            SampleDocuments.field_1.Left = "222pt";
            paragraph = SampleDocuments.field_1.AddParagraph(".");
            paragraph.Format.Font.Size = 5;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "152pt";
            SampleDocuments.field_1.Left = "222pt";
            paragraph = SampleDocuments.field_1.AddParagraph("");
            paragraph.Format.Font.Size = 5;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            table.Rows.Height = "62pt";
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "98pt";
            SampleDocuments.field_1.Left = "28pt";
            paragraph = SampleDocuments.field_1.AddParagraph("1 ");
            paragraph.Format.Font.Size = 5;
            #endregion

            #region  4-6 
            //  4-6 receiver
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "159.5 pt";
            SampleDocuments.field_1.Left = "28pt";
            table = SampleDocuments.field_1.AddTable();
            table.Borders.Width = "1pt";
            table.Borders.Color = TableBorder;
            table.Borders.Top.Visible = false;
            column = table.AddColumn(Unit.FromPoint(197));
            column = table.AddColumn(Unit.FromPoint(73));
            row = table.AddRow();
            row.TopPadding = "0pt";
            row.Cells[0].Borders.Right.Visible = false;
            SampleDocuments.field_1 = row.Cells[1].AddTextFrame();
            table2 = SampleDocuments.field_1.AddTable();
            table2.Borders.Width = "1 pt";
            table2.BottomPadding = 0;
            table2.Borders.Color = TableBorder;
            table2.Borders.Style = BorderStyle.DashDotDot;
            column = table2.AddColumn();
            column.RightPadding = "2pt";
            column.LeftPadding = "2pt";
            row = table2.AddRow();
            row.Cells[0].Borders.Right.Visible = false;
            row.Cells[0].Borders.Top.Visible = false;
            row.Cells[0].Borders.Style = BorderStyle.Single;
            //field 2 data data 4 digit code
            paragraph = row.Cells[0].AddParagraph("5678");
            paragraph.Format.Font.Size = 12;
            paragraph.Format.Font.Bold = true;
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            row = table2.AddRow();
            row.Cells[0].Borders.Right.Visible = false;
            paragraph = row.Cells[0].AddParagraph("1234567");
            paragraph.Format.Font.Size = 10;
            paragraph.Format.Font.Bold = true;
            paragraph.Format.Alignment = ParagraphAlignment.Center;

            //field e-mail
            row = table2.AddRow();
            paragraph = row.Cells[0].AddParagraph("receiver@domain.com");
            paragraph.Format.Font.Size = 6;
            row.Cells[0].VerticalAlignment = VerticalAlignment.Bottom;
            row.Cells[0].Borders.Visible = false;
            row = table2.AddRow();
            row.Cells[0].Borders.Visible = false;
            table2.Rows.HeightRule = RowHeightRule.Exactly;
            table2.Rows.Height = "15pt";
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "165pt";
            SampleDocuments.field_1.Left = "224pt";
            paragraph = SampleDocuments.field_1.AddParagraph("2");
            paragraph.Format.Font.Size = 5;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "180pt";
            SampleDocuments.field_1.Left = "224pt";
            paragraph = SampleDocuments.field_1.AddParagraph("3");
            paragraph.Format.Font.Size = 5;

            // email field
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "195pt";
            SampleDocuments.field_1.Left = "222pt";
            paragraph = SampleDocuments.field_1.AddParagraph(".");
            paragraph.Format.Font.Size = 5;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "208pt";
            SampleDocuments.field_1.Left = "222pt";
            paragraph = SampleDocuments.field_1.AddParagraph(".");
            paragraph.Format.Font.Size = 5;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "215pt";
            SampleDocuments.field_1.Left = "222pt";
            paragraph = SampleDocuments.field_1.AddParagraph("");
            paragraph.Format.Font.Size = 5;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            table.Rows.Height = "62pt";
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "165pt";
            SampleDocuments.field_1.Left = "28pt";
            paragraph = SampleDocuments.field_1.AddParagraph("4 ");
            paragraph.Format.Font.Size = 5;
            #endregion

            #region  7-8 


            // field 7 sender orders 2 rows with different height
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "98pt";
            SampleDocuments.field_1.Left = "299pt";
            paragraph = SampleDocuments.field_1.AddParagraph("7  ");
            paragraph.Format.Font.Size = 5;


            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "96.5pt";
            SampleDocuments.field_1.Left = "298pt";
            table = SampleDocuments.field_1.AddTable();
            table.Borders.Width = "1pt";
            table.Borders.Color = TableBorder;
            table.Borders.Top.Visible = false;
            column = table.AddColumn(Unit.FromPoint(108));
            column = table.AddColumn(Unit.FromPoint(140));
            row = table.AddRow();
            table.Rows.HeightRule = RowHeightRule.Exactly;
            table.Rows.Height = "16pt";
            row.Cells[0].Borders.Bottom.Visible = false;
            row.Cells[0].Borders.Right.Style = BorderStyle.DashDot;
            row.Cells[1].Borders.Bottom.Style = BorderStyle.DashDot;

            field_2 = row.Cells[1].AddTextFrame();
            table2 = field_2.AddTable();

            column = table2.AddColumn(Unit.FromPoint(6));
            column = table2.AddColumn(Unit.FromPoint(132));
            row = table2.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "16 pt";
            paragraph = row.Cells[0].AddParagraph("8");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.LeftIndent = "-3  pt";
            //    8
            paragraph = row.Cells[1].AddParagraph();

            row = table.AddRow();
            row.Height = "38pt";
            row.Cells[0].Borders.Right.Visible = false;
            row.Cells[0].MergeRight = 1;
            //paragraph = row.Cells[0].AddParagraph(some_text);

            //   table.SetEdge(0, 0, 2, 3, Edge.Box, BorderStyle.Single, 1.5, Colors.Black);

            #endregion

            #region  9  

            //field 9 - sender documents
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "152.5pt";
            SampleDocuments.field_1.Left = "298pt";
            table = SampleDocuments.field_1.AddTable();
            column = table.AddColumn(Unit.FromPoint(248));
            table.Borders.Color = TableBorder;
            table.Borders.Top.Visible = false;
            table.Borders.Left.Visible = false;
            table.Borders.Bottom.Visible = false;
            table.Borders.Width = "1pt";
            row = table.AddRow();
            table.Rows.HeightRule = RowHeightRule.Exactly;
            row.Height = "7pt";
            row.VerticalAlignment = VerticalAlignment.Bottom;
            row.Cells[0].Borders.Visible = false;
            row.Cells[0].Borders.Right.Visible = true;
            paragraph = row.Cells[0].AddParagraph("9 ,  ");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.Font.Bold = true;
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            row = table.AddRow();
            row.Height = "42pt";
            paragraph = row.Cells[0].AddParagraph("field 9");

            #endregion

            #region  10-12    
            // field 10 -12 Dest. Station and Railways


            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "222 pt";
            SampleDocuments.field_1.Left = "28pt";
            table = SampleDocuments.field_1.AddTable();
            column = table.AddColumn(Unit.FromPoint(112.5));
            column = table.AddColumn(Unit.FromPoint(157.5));
            table.Borders.Width = "1pt";
            table.Borders.Color = TableBorder;
            table.Borders.Top.Visible = false;
            row = table.AddRow();
            table.Rows.HeightRule = RowHeightRule.Exactly;
            row.Cells[0].Borders.Bottom.Visible = false;
            row.Height = "16pt";
            paragraph = row.Cells[0].AddParagraph("10    ");
            paragraph.Format.Font.Size = 5;

            // field 11-12
            field_2 = row.Cells[1].AddTextFrame();
            table2 = field_2.AddTable();
            table2.Borders.Color = TableBorder;
            table2.Borders.Width = "1pt";
            table2.Borders.Top.Visible = false;
            column = table2.AddColumn(Unit.FromPoint(68));
            column = table2.AddColumn(Unit.FromPoint(27));
            column = table2.AddColumn(Unit.FromPoint(62));
            row = table2.AddRow();
            table2.Rows.HeightRule = RowHeightRule.Exactly;
            row.Height = "16";
            field_1 = row.Cells[2].AddTextFrame();
            table3 = field_1.AddTable();
            table3.Borders.Width = "0.2pt";
            table3.Borders.Style = BorderStyle.DashSmallGap;
            table3.Borders.Color = TableBorder;
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            row = table3.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "16pt";
            Int32 code = 320210;
            Int32 delitel = 100000;
            Int32 dig1, dig2;
            for (int i = 0; i < 6; i++)
            {
                dig1 = code / delitel;
                dig2 = code % delitel;
                paragraph = row.Cells[i].AddParagraph(dig1.ToString());
                paragraph.Format.Alignment = ParagraphAlignment.Center;
                paragraph.Format.Font.Bold = true;
                paragraph.Format.Font.Size = 14;
                row.Cells[i].VerticalAlignment = VerticalAlignment.Center;

                code = dig2;
                delitel = delitel / 10;
            }

            row.Cells[5].Borders.Right.Visible = false;
            row = table.AddRow();
            row.Height = "32pt";
            row.Cells[0].MergeRight = 1;
            row.Cells[0].Borders.Top.Visible = false;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "223";
            SampleDocuments.field_1.Left = "140";
            paragraph = SampleDocuments.field_1.AddParagraph("11");
            paragraph.Format.Font.Size = 5;
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "223";
            SampleDocuments.field_1.Left = "206";
            paragraph = SampleDocuments.field_1.AddParagraph("12");
            paragraph.Format.Font.Size = 5;

            #endregion

            #region  16-17    

            // field 16-17 Station and railways sender 



            field_1 = section.AddTextFrame();
            SampleDocuments.field_1 = section.AddTextFrame();
            SampleDocuments.field_1.RelativeVertical = RelativeVertical.Page;
            SampleDocuments.field_1.Top = "201.5pt";
            SampleDocuments.field_1.Left = "298pt";
            table = SampleDocuments.field_1.AddTable();
            column = table.AddColumn(Unit.FromPoint(157.5));
            column = table.AddColumn(Unit.FromPoint(90.5));
            table.Borders.Width = "1pt";
            table.Borders.Color = TableBorder;
            row = table.AddRow();
            table.Rows.HeightRule = RowHeightRule.Exactly;
            row.Cells[0].Borders.Bottom.Visible = false;
            row.Height = "16pt";
            paragraph = row.Cells[0].AddParagraph("16    ");
            paragraph.Format.Font.Size = 5;
            field_2 = row.Cells[1].AddTextFrame();
            table2 = field_2.AddTable();
            column = table2.AddColumn(Unit.FromPoint(27));
            column = table2.AddColumn(Unit.FromPoint(64));
            row = table2.AddRow();
            table2.Borders.Width = "0.5 pt";
            table2.Borders.Color = TableBorder;
            table2.Borders.Top.Visible = false;
            row.Cells[1].Borders.Right.Visible = false;
            table2.Rows.HeightRule = RowHeightRule.Exactly;
            row.Height = "16";
            field_2 = section.AddTextFrame();
            field_2.RelativeVertical = RelativeVertical.Page;
            //  field_2.RelativeHorizontal = RelativeHorizontal.Column;
            field_2.Top = "202 pt";
            field_2.Left = "452 pt";
            paragraph = field_2.AddParagraph("17");
            paragraph.Format.Font.Size = 5;


            field_1 = row.Cells[1].AddTextFrame();
            table3 = field_1.AddTable();
            table3.Borders.Width = "0.2pt";
            table3.Borders.Style = BorderStyle.DashSmallGap;
            table3.Borders.Color = TableBorder;
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            column = table3.AddColumn(Unit.FromPoint(10.5));
            row = table3.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "16pt";
            code = 320632;
            delitel = 100000;
            for (int i = 0; i < 6; i++)
            {
                dig1 = code / delitel;
                dig2 = code % delitel;
                paragraph = row.Cells[i].AddParagraph(dig1.ToString());
                paragraph.Format.Alignment = ParagraphAlignment.Center;
                paragraph.Format.Font.Bold = true;
                paragraph.Format.Font.Size = 14;
                row.Cells[i].VerticalAlignment = VerticalAlignment.Center;

                code = dig2;
                delitel = delitel / 10;
            }
            row = table.AddRow();
            row.Height = "21.5pt";
            row.Cells[0].MergeRight = 1;
            row.Cells[0].Borders.Top.Visible = false;
            paragraph = row.Cells[0].AddParagraph("Some data for this field 16");
            #endregion

            #region  18  

            //field 18 customs notes
            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "241  pt";
            field_1.Left = "298 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            column = table.AddColumn(Unit.FromPoint(248));
            row = table.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "7 pt";
            row.Cells[0].Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("18  ");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "41 pt";
            paragraph = row.Cells[0].AddParagraph("some text for field 18");
            paragraph.Format.Font.Size = 14;

            #endregion

            #region  19  

            //field 19 number carriage

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "290 pt";
            field_1.Left = "298 pt";

            table = field_1.AddTable();
            column = table.AddColumn(Unit.FromPoint(103));
            column = table.AddColumn(Unit.FromPoint(38));
            column = table.AddColumn(Unit.FromPoint(16.5));
            column = table.AddColumn(Unit.FromPoint(53));
            column = table.AddColumn(Unit.FromPoint(37.5));
            row = table.AddRow();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "7 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("19  ");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "57 pt";
            table.Borders.Right.Style = BorderStyle.DashDotDot;
            row.Cells[4].Borders.Right.Style = BorderStyle.Single;

            #endregion

            #region  13 

            //field 13 payer

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "271 pt";
            field_1.Left = "28 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            column = table.AddColumn(Unit.FromPoint(174));
            column = table.AddColumn(Unit.FromPoint(96));
            row = table.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "16 pt";
            row.Cells[0].Borders.Bottom.Visible = false;
            field_2 = row.Cells[0].AddTextFrame();
            //field_2.RelativeVertical = RelativeVertical.Line;
            field_2.Top = 0;
            field_2.Left = 0;
            paragraph = field_2.AddParagraph("13 ");
            paragraph.Format.Font.Size = 5;
            field_2 = row.Cells[1].AddTextFrame();
            table2 = field_2.AddTable();
            column = table2.AddColumn(Unit.FromPoint(16));
            column = table2.AddColumn(Unit.FromPoint(11.4));
            column = table2.AddColumn(Unit.FromPoint(11.4));
            column = table2.AddColumn(Unit.FromPoint(11.4));
            column = table2.AddColumn(Unit.FromPoint(11.4));
            column = table2.AddColumn(Unit.FromPoint(11.4));
            column = table2.AddColumn(Unit.FromPoint(11.4));
            column = table2.AddColumn(Unit.FromPoint(11.4));

            row = table2.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "16pt";
            row.Cells[0].Borders.Right.Style = BorderStyle.DashDotDot;
            row.Cells[0].Borders.Right.Width = "0.5 pt";
            row.Cells[0].Borders.Right.Color = TableBorder;


            field_2 = row.Cells[0].AddTextFrame();
            field_2.Left = "0 pt";
            table3 = field_2.AddTable();
            column = table3.AddColumn(Unit.FromPoint(16));
            row2 = table3.AddRow();
            row2.HeightRule = RowHeightRule.Exactly;
            row2.Height = "7 pt";
            paragraph = row2.Cells[0].AddParagraph("14");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            row2 = table3.AddRow();
            row2.Height = "9 pt";

            code = 2000023;
            delitel = 1000000;
            for (int i = 0; i < 7; i++)
            {
                dig1 = code / delitel;
                dig2 = code % delitel;
                paragraph = row.Cells[i + 1].AddParagraph(dig1.ToString());
                paragraph.Format.Alignment = ParagraphAlignment.Center;
                paragraph.Format.Font.Bold = true;
                paragraph.Format.Font.Size = 14;
                row.Cells[i + 1].VerticalAlignment = VerticalAlignment.Center;

                code = dig2;
                delitel = delitel / 10;
            }
            row = table.AddRow();
            row.Height = "21 pt";
            row.Cells[0].MergeRight = 1;
            paragraph = row.Cells[0].AddParagraph("some data for field 13");
            #endregion

            #region 15   
            // field 15 optional marks

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "310 pt";
            field_1.Left = "28 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            column = table.AddColumn(Unit.FromPoint(270));
            row = table.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "9 pt";
            row.Cells[0].Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("15     ");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "35  pt";
            #endregion

            #region  20 

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "355 pt";
            field_1.Left = "28 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(53));
            column = table.AddColumn(Unit.FromPoint(55));
            column = table.AddColumn(Unit.FromPoint(70));
            column = table.AddColumn(Unit.FromPoint(92));
            column = table.AddColumn(Unit.FromPoint(70));
            row = table.AddRow();
            row.Height = "16 pt";
            row.Cells[0].MergeRight = 2;
            row.Cells[0].Borders.Bottom.Visible = false;
            //field 20 - 21 -22 data fe - checked a8 unchecked
            paragraph = row.Cells[0].AddParagraph("20  ");
            paragraph.Format.Font.Size = 5;
            field_2 = row.Cells[3].AddTextFrame();
            field_2.Width = "10 pt";
            field_2.Height = "6 pt";
            field_2.MarginRight = "1 pt";
            field_2.MarginBottom = "1 pt";
            field_2.WrapFormat.Style = WrapStyle.Through;
            field_2.WrapFormat.DistanceTop = "-2 pt";
            field_2.WrapFormat.DistanceLeft = 0;
            field_2.WrapFormat.DistanceRight = 0;
            paragraph = field_2.AddParagraph("21");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[3].AddParagraph();
            paragraph.AddFormattedText("\u00fe", new Font("Wingdings"));  //checked-unchecked field 21
            paragraph.Format.Alignment = ParagraphAlignment.Right;
            paragraph.Format.Font.Size = 18;
            row.Cells[3].VerticalAlignment = VerticalAlignment.Center;

            field_2 = row.Cells[4].AddTextFrame();
            field_2.Width = "10 pt";
            field_2.Height = "6 pt";
            field_2.MarginRight = "1 pt";
            field_2.MarginBottom = "1 pt";
            field_2.WrapFormat.Style = WrapStyle.Through;
            field_2.WrapFormat.DistanceTop = "-2 pt";
            field_2.WrapFormat.DistanceLeft = 0;
            field_2.WrapFormat.DistanceRight = 0;
            paragraph = field_2.AddParagraph("22");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[4].AddParagraph();
            paragraph.AddFormattedText("\u00fe", new Font("Wingdings"));  //checked-unchecked field 21
            paragraph.Format.Alignment = ParagraphAlignment.Right;
            paragraph.Format.Font.Size = 18;
            row.Cells[4].VerticalAlignment = VerticalAlignment.Center;
            row = table.AddRow();
            row.Height = "11 pt";
            row.Borders.Top.Visible = false;
            row.Borders.Bottom.Visible = false;
            row.Cells[2].MergeRight = 1;
            paragraph = row.Cells[0].AddParagraph("");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[1].AddParagraph("");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[2].AddParagraph("");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.Alignment = ParagraphAlignment.Left;
            paragraph = row.Cells[4].AddParagraph(" ");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            //    
            row = table.AddRow();
            row.Height = "102 pt";
            row.Borders.Right.Visible = false;
            row.Borders.Bottom.Visible = false;
            row.Cells[4].Borders.Right.Visible = true;
            row.Cells[2].MergeRight = 1;
            row = table.AddRow();
            row.Height = "32 pt";
            row.Cells[0].MergeRight = 4;
            row.Borders.Top.Visible = false;
            row.Borders.Bottom.Style = BorderStyle.DashDot;
            row = table.AddRow();
            row.Height = "8 pt";
            row.Cells[0].MergeRight = 4;
            paragraph = row.Cells[0].AddParagraph(" ()");
            paragraph.Format.Font.Size = 5;
            row.Borders.Bottom.Visible = false;
            row = table.AddRow();
            row.Height = "34 pt";
            row.Cells[0].MergeRight = 4;

            #endregion

            #region  23-25  
            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "355 pt";
            field_1.Left = "368 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Borders.Style = BorderStyle.Single;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(54));
            column = table.AddColumn(Unit.FromPoint(62));
            column = table.AddColumn(Unit.FromPoint(62));
            row = table.AddRow();
            row.Height = "12.2 pt";
            row.Format.Font.Size = 5;
            paragraph = row.Cells[0].AddParagraph("23  ");
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[1].AddParagraph("24  ,");
            paragraph.AddText(" ");
            paragraph.Format.Font.Size = 4;
            row.Cells[1].Format.LeftIndent = -2;
            row.Cells[1].Format.RightIndent = -2;
            paragraph.Format.LineSpacingRule = LineSpacingRule.Exactly;
            paragraph.Format.LineSpacing = 5;
            paragraph = row.Cells[2].AddParagraph("24  , ");
            paragraph.AddText("");
            paragraph.Format.Font.Size = 4;
            row.Cells[2].Format.LeftIndent = -2;
            row.Cells[2].Format.RightIndent = -2;
            paragraph.Format.LineSpacingRule = LineSpacingRule.Exactly;
            paragraph.Format.LineSpacing = 5;
            row.Cells[1].Borders.Right.Style = BorderStyle.DashDot;
            row.Cells[1].Borders.Bottom.Visible = false;
            row = table.AddRow();
            row.Height = "60 pt";
            row.Cells[1].Borders.Right.Style = BorderStyle.DashDot;
            row.Cells[1].Borders.Top.Visible = false;
            field_2 = section.AddTextFrame();
            field_2.RelativeVertical = RelativeVertical.Page;
            field_2.Top = "382 pt";
            field_2.Left = "420 pt";
            field_2.Height = "40 pt";
            field_2.Width = "124 pt";
            paragraph = field_2.AddParagraph("      ");

            #endregion

            #region  26-28

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "428.5  pt";
            field_1.Left = "368 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(103));
            column = table.AddColumn(Unit.FromPoint(75));
            row = table.AddRow();
            row.Height = "8 pt";
            row.Format.Font.Size = 5;
            paragraph = row.Cells[0].AddParagraph("26   ");
            paragraph = row.Cells[1].AddParagraph("27  ");
            row.Borders.Bottom.Visible = false;
            row = table.AddRow();
            row.Height = "80.5 pt";
            row.Cells[1].MergeDown = 2;
            row = table.AddRow();
            row.Height = "15.5 pt";
            row.Cells[0].Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("28      ()");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "26.5 pt";



            #endregion

            #region 30-45 tariffs fields

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "561 pt";
            field_1.Left = "28 pt";

            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(72));
            column = table.AddColumn(Unit.FromPoint(42));
            column = table.AddColumn(Unit.FromPoint(54));
            column = table.AddColumn(Unit.FromPoint(54));
            column = table.AddColumn(Unit.FromPoint(54));
            row = table.AddRow();
            row.Height = "8 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("30  ");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[2].AddParagraph("31");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[3].AddParagraph("32");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[4].AddParagraph("33");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "18.5 pt";
            row.Borders.Bottom.Style = BorderStyle.DashDot;
            row.Cells[0].Borders.Bottom.Visible = false;
            row.Cells[0].VerticalAlignment = VerticalAlignment.Bottom;
            paragraph = row.Cells[0].AddParagraph(" , ");
            paragraph.Format.Font.Size = "5 pt";

            row = table.AddRow();
            row.Height = "8 pt";
            row.Borders.Bottom.Visible = false;
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[2].AddParagraph("35");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[3].AddParagraph("36");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[4].AddParagraph("37");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "18.5 pt";
            row.Borders.Bottom.Style = BorderStyle.Single;
            row.Cells[0].Borders.Bottom.Visible = false;
            row.Cells[0].VerticalAlignment = VerticalAlignment.Bottom;
            paragraph = row.Cells[0].AddParagraph("");
            paragraph.Format.Font.Size = "5 pt";
            paragraph.Format.Alignment = ParagraphAlignment.Right;
            row.Cells[1].Borders.Bottom.Style = BorderStyle.DashDot;

            row = table.AddRow();
            row.Height = "8 pt";
            row.Borders.Bottom.Visible = false;
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[2].AddParagraph("39");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[3].AddParagraph("40");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[4].AddParagraph("41");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "18.5 pt";
            row.Borders.Bottom.Style = BorderStyle.DashDot;
            row.Cells[0].Borders.Bottom.Visible = false;
            row.Cells[0].VerticalAlignment = VerticalAlignment.Bottom;
            paragraph = row.Cells[0].AddParagraph(" ");
            row.Cells[1].Borders.Top.Visible = false;
            paragraph.Format.Font.Size = "5 pt";
            paragraph.Format.Alignment = ParagraphAlignment.Right;

            row = table.AddRow();
            row.Height = "8 pt";
            row.Borders.Bottom.Visible = false;
            paragraph.Format.Font.Size = 5;
            row.Cells[0].MergeRight = 1;
            paragraph = row.Cells[2].AddParagraph("43");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[3].AddParagraph("44");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[4].AddParagraph("45");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "18.5 pt";

            row.Cells[0].Borders.Bottom.Visible = false;
            row.Cells[0].MergeRight = 1;
            row.Borders.Bottom.Style = BorderStyle.Single;
            row.Cells[0].Borders.Bottom.Style = BorderStyle.Single;
            row.Borders.Visible = true;

            #endregion

            #region  47
            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "671 pt";
            field_1.Left = "28 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(9.3));
            column = table.AddColumn(Unit.FromPoint(266.8));
            row = table.AddRow();
            row.Height = "15.9 pt";
            paragraph = row.Cells[0].AddParagraph("47");
            row.Cells[0].Borders.Right.Visible = false;
            paragraph.Format.Font.Size = 5;
            paragraph.Format.LeftIndent = "-2 pt";

            #endregion

            #region  49  

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "687.7 pt";
            field_1.Left = "28 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(276));
            row = table.AddRow();
            row.Height = "8 pt";
            paragraph = row.Cells[0].AddParagraph("49  ");
            paragraph.Format.Font.Size = 5;
            row.Borders.Bottom.Visible = false;
            row = table.AddRow();
            row.Height = "30 pt";

            #endregion

            #region  51-56

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "726.6 pt";
            field_1.Left = "28 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(147));
            column = table.AddColumn(Unit.FromPoint(129));
            row = table.AddRow();
            row.Height = "9 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("51    ");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[1].AddParagraph("52    ");
            paragraph.Format.Font.Size = 5;

            //   51-52
            row = table.AddRow();
            row.Height = "29 pt";

            row = table.AddRow();
            row.Height = "8 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("55    ");
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[1].AddParagraph("56    ");
            paragraph.Format.Font.Size = 5;

            //   55 -56
            row = table.AddRow();
            row.Height = "21 pt";
            row.Borders.Bottom.Visible = false;
            row = table.AddRow();
            row.Height = "9 pt";
            paragraph = row.Cells[0].AddParagraph("");
            paragraph.Format.Font.Size = 5;

            #endregion

            #region  29

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "561 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Color = TableBorder;
            table.Borders.Width = "1 pt";
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(18));
            column = table.AddColumn(Unit.FromPoint(30));
            column = table.AddColumn(Unit.FromPoint(11));
            column = table.AddColumn(Unit.FromPoint(42));
            column = table.AddColumn(Unit.FromPoint(11));
            column = table.AddColumn(Unit.FromPoint(37));
            column = table.AddColumn(Unit.FromPoint(12));
            column = table.AddColumn(Unit.FromPoint(39));
            column = table.AddColumn(Unit.FromPoint(12));
            column = table.AddColumn(Unit.FromPoint(30));
            row = table.AddRow();
            row.Height = "6 pt";
            //row.Borders.Right.Visible = false;
            row.Borders.Bottom.Visible = false;
            row.Cells[0].MergeRight = 9;
            paragraph = row.Cells[0].AddParagraph("29 ");
            paragraph.Format.Font.Size = 5;
            paragraph.Format.LeftIndent = "-2 pt";

            row = table.AddRow();
            row.Height = "10 pt";
            row.Borders.Right.Visible = false;
            row.Cells[9].Borders.Right.Visible = true;
            //     fe - checked a8 unchecked
            paragraph = row.Cells[0].AddParagraph();
            paragraph.AddFormattedText("\u00fe", new Font("Wingdings"));
            paragraph.Format.Font.Size = 12;

            paragraph = row.Cells[1].AddParagraph("");
            paragraph.Format.Font.Size = 6;

            paragraph = row.Cells[2].AddParagraph();
            paragraph.AddFormattedText("\u00a8", new Font("Wingdings"));
            paragraph.Format.Font.Size = 12;

            paragraph = row.Cells[3].AddParagraph("");
            paragraph.Format.Font.Size = 6;

            paragraph = row.Cells[4].AddParagraph();
            paragraph.AddFormattedText("\u00a8", new Font("Wingdings"));
            paragraph.Format.Font.Size = 12;

            paragraph = row.Cells[5].AddParagraph("/ ");
            paragraph.AddText("");
            paragraph.Format.Font.Size = 6;
            paragraph.Format.LineSpacingRule = LineSpacingRule.Exactly;
            paragraph.Format.LineSpacing = "3 pt";

            paragraph = row.Cells[6].AddParagraph();
            paragraph.AddFormattedText("\u00a8", new Font("Wingdings"));
            paragraph.Format.Font.Size = 12;

            paragraph = row.Cells[7].AddParagraph("");
            paragraph.Format.Font.Size = 6;


            paragraph = row.Cells[8].AddParagraph();
            paragraph.AddFormattedText("\u00a8", new Font("Wingdings"));
            paragraph.Format.Font.Size = 12;

            paragraph = row.Cells[9].AddParagraph("/");

            paragraph.Format.Font.Size = 6;
            paragraph.Format.LineSpacingRule = LineSpacingRule.Exactly;
            paragraph.Format.LineSpacing = "3 pt";


            #endregion

            #region  34

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "578 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(242));
            row = table.AddRow();
            row.Height = "8.5 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("34    ()");
            paragraph.Format.LeftIndent = "-2 pt";
            paragraph.Format.Font.Size = 5;
            // 
            row = table.AddRow();
            row.Height = "19 pt";

            #endregion

            #region  38

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "606.5 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(242));
            row = table.AddRow();
            row.Height = "7 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("38 ");
            paragraph.Format.LeftIndent = "-2 pt";
            paragraph.Format.Font.Size = 5;
            // 
            row = table.AddRow();
            row.Height = "10 pt";

            #endregion

            #region  42

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "624.5 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(242));
            row = table.AddRow();
            row.Height = "7 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("42    ()");
            paragraph.Format.LeftIndent = "-2 pt";
            paragraph.Format.Font.Size = 5;
            // 
            row = table.AddRow();
            row.Height = "20 pt";

            #endregion

            #region  46

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "652.5 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(242));
            row = table.AddRow();
            row.Height = "7 pt";
            row.Borders.Bottom.Visible = false;
            paragraph = row.Cells[0].AddParagraph("46 ");
            paragraph.Format.LeftIndent = "-2 pt";
            paragraph.Format.Font.Size = 5;
            // 
            row = table.AddRow();
            row.Height = "10.5 pt";

            #endregion

            #region  48
            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "671 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(9.3));
            column = table.AddColumn(Unit.FromPoint(232.7));
            row = table.AddRow();
            row.Height = "15.9 pt";
            paragraph = row.Cells[0].AddParagraph("48");
            row.Cells[0].Borders.Right.Visible = false;
            paragraph.Format.Font.Size = 5;
            paragraph.Format.LeftIndent = "-2 pt";

            #endregion

            #region  50  

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "687.7 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(242));
            row = table.AddRow();
            row.Height = "8 pt";
            paragraph = row.Cells[0].AddParagraph("50  ");
            paragraph.Format.Font.Size = 5;
            row.Borders.Bottom.Visible = false;
            row = table.AddRow();
            row.Height = "30 pt";

            #endregion

            #region  53

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "726.6 pt";
            field_1.Left = "304 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(43.7));
            column = table.AddColumn(Unit.FromPoint(65));

            row = table.AddRow();
            row.Height = "12.5 pt";
            paragraph.Format.Font.Size = 5;
            row.Cells[0].MergeRight = 1;
            row.Borders.Bottom.Visible = false;
            paragraph.Format.Font.Size = 5;
            paragraph = row.Cells[0].AddParagraph("53   ");
            paragraph.AddLineBreak();
            paragraph.AddText(" ");
            paragraph.Format.Font.Size = 5;
            row = table.AddRow();
            row.Height = "39 pt";
            row.Cells[0].MergeRight = 1;
            row.Cells[0].Borders.Bottom.Visible = false;
            //   53 
            paragraph = row.Cells[0].AddParagraph();
            row = table.AddRow();
            row.Height = "9 pt";
            row.Borders.Bottom.Visible = false;
            row.Cells[0].Borders.Right.Visible = false;
            row.Cells[1].Borders.Right.Visible = true;
            paragraph = row.Cells[0].AddParagraph("");
            paragraph.Format.Font.Size = "5 pt";
            paragraph = row.Cells[1].AddParagraph("");
            paragraph.Format.Font.Size = "5 pt";

            row = table.AddRow();
            row.Height = "16.5 pt";
            row.Cells[0].Borders.Right.Visible = false;
            field_2 = row.Cells[1].AddTextFrame();
            table2 = field_2.AddTable();
            table2.Borders.Top.Style = BorderStyle.DashDot;
            table2.Rows.HeightRule = RowHeightRule.Exactly;
            table2.Borders.Color = TableBorder;
            table2.Borders.Width = "1 pt";
            column = table2.AddColumn(Unit.FromPoint(10.7));
            column = table2.AddColumn(Unit.FromPoint(10.7));
            column = table2.AddColumn(Unit.FromPoint(10.7));
            column = table2.AddColumn(Unit.FromPoint(10.7));
            column = table2.AddColumn(Unit.FromPoint(10.7));
            column = table2.AddColumn(Unit.FromPoint(10.7));
            row = table2.AddRow();

            row.Height = "13 pt";
            row.Borders.Bottom.Visible = false;
            row.Borders.Right.Visible = false;
            DateTime SampleDate = new DateTime(2017, 10, 07);
            int y = SampleDate.Year;
            int m = SampleDate.Month;
            int d = SampleDate.Day;

            //   
            row.Format.Font.Size = 12;
            row.Format.Font.Bold = true;
            row.VerticalAlignment = VerticalAlignment.Bottom;
            row.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[4].AddParagraph(((y % 1000) / 10).ToString());
            paragraph = row.Cells[5].AddParagraph(((y % 1000) % 10).ToString());
            paragraph = row.Cells[2].AddParagraph((m / 10).ToString());
            paragraph = row.Cells[3].AddParagraph((m % 10).ToString());
            paragraph = row.Cells[0].AddParagraph((d / 10).ToString());
            paragraph = row.Cells[1].AddParagraph((d % 10).ToString());
            row = table2.AddRow();
            row.Height = "3 pt";
            row.Borders.Bottom.Visible = false;
            row.Borders.Right.Visible = true;


            #endregion

            #region  54  

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "726.6 pt";
            field_1.Left = "412.7 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(42));
            column = table.AddColumn(Unit.FromPoint(18.5));
            column = table.AddColumn(Unit.FromPoint(3));
            column = table.AddColumn(Unit.FromPoint(64.5));
            column = table.AddColumn(Unit.FromPoint(5.2));
            row = table.AddRow();
            row.Height = "6 pt";
            row.Cells[0].MergeRight = 4;
            paragraph = row.Cells[0].AddParagraph("54  ");
            paragraph.Format.Font.Size = 5;
            row.Borders.Bottom.Visible = false;
            // 
            row = table.AddRow();
            row.Height = "13 pt";
            row.Borders.Bottom.Visible = false;
            row.Borders.Right.Visible = false;
            row.Cells[4].Borders.Right.Visible = true;
            row.Cells[4].Borders.Bottom.Visible = false;
            field_2 = row.Cells[1].AddTextFrame();
            field_3 = row.Cells[3].AddTextFrame();
            table2 = field_2.AddTable();
            table2.Borders.Width = "0.8 pt";
            table2.Borders.Color = TableBorder;
            column = table2.AddColumn(Unit.FromPoint(9.4));
            column = table2.AddColumn(Unit.FromPoint(9.4));
            row = table2.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "12 pt";
            row.Cells[0].Borders.Right.Style = BorderStyle.DashDotDot;

            row.Format.Font.Size = 9;
            row.Format.Font.Bold = true;
            row.VerticalAlignment = VerticalAlignment.Center;
            //add dummy data rw_code
            int rw_code = 48;
            paragraph = row.Cells[0].AddParagraph((rw_code / 10).ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[1].AddParagraph((rw_code % 10).ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;


            table2 = field_3.AddTable();
            table2.Borders.Width = "0.8 pt";
            table2.Borders.Color = TableBorder;
            column = table2.AddColumn(Unit.FromPoint(9.7));
            column = table2.AddColumn(Unit.FromPoint(9.7));
            column = table2.AddColumn(Unit.FromPoint(9.7));
            column = table2.AddColumn(Unit.FromPoint(9.7));
            column = table2.AddColumn(Unit.FromPoint(9.7));
            column = table2.AddColumn(Unit.FromPoint(9.7));
            row = table2.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "12 pt";
            row.Cells[5].Borders.Right.Style = BorderStyle.Single;
            
            row.Format.Font.Size = 9;
            row.Format.Font.Bold = true;
            row.VerticalAlignment = VerticalAlignment.Center;
            row.Borders.Right.Style = BorderStyle.DashDotDot;
            row.Cells[5].Borders.Right.Style = BorderStyle.Single;
            //add dummy data

            String dummy_code = "504400";
            paragraph = row.Cells[0].AddParagraph(dummy_code[0].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[1].AddParagraph(dummy_code[1].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[2].AddParagraph(dummy_code[2].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[3].AddParagraph(dummy_code[3].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[4].AddParagraph(dummy_code[4].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[5].AddParagraph(dummy_code[5].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;

            row = table.AddRow();
            row.Height = "3.5 pt";
            field_4 = row.Cells[1].AddTextFrame();
            field_4.RelativeVertical = RelativeVertical.Line;
            field_4.Top = "3 pt";
            row.Borders.Bottom.Visible = false;
            row.Borders.Right.Visible = false;
            row.Cells[4].Borders.Right.Visible = true;
            row.Cells[4].Borders.Top.Visible = false;

            row = table.AddRow();
            row.Height = "11.2 pt";
            

            row.Cells[1].MergeRight = 2;
            row.Borders.Bottom.Visible = false;
            row.Borders.Right.Visible = false;
            row.Cells[4].Borders.Right.Visible = true;
            row.Cells[4].Borders.Top.Visible = false;
            row.VerticalAlignment = VerticalAlignment.Center;
            paragraph = row.Cells[0].AddParagraph("");
            paragraph.Format.Font.Size = 6;
            paragraph.Format.Alignment = ParagraphAlignment.Right;

          
            table3 = field_4.AddTable();
            table3.Borders.Color = TableBorder;
            table3.Borders.Width = "0.8 pt";
            column = table3.AddColumn(Unit.FromPoint(9.9));
            column = table3.AddColumn(Unit.FromPoint(9.9));
            column = table3.AddColumn(Unit.FromPoint(9.9));
            column = table3.AddColumn(Unit.FromPoint(9.9));
            column = table3.AddColumn(Unit.FromPoint(9.9));
            column = table3.AddColumn(Unit.FromPoint(9.9));
            column = table3.AddColumn(Unit.FromPoint(9.9));
            column = table3.AddColumn(Unit.FromPoint(9.9));
            row = table3.AddRow();
            row.HeightRule = RowHeightRule.Exactly;
            row.Height = "11 pt";
            row.Cells[7].Borders.Right.Style = BorderStyle.Single;
            row.Format.Font.Size = 9;
            row.Format.Font.Bold = true;
            row.VerticalAlignment = VerticalAlignment.Center;
            row.Borders.Right.Style = BorderStyle.DashDotDot;
            row.Cells[7].Borders.Right.Style = BorderStyle.Single;
            // some dummy data for doc. number
            String doc_number = "38768909";
            paragraph = row.Cells[0].AddParagraph(doc_number[0].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[1].AddParagraph(doc_number[1].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[2].AddParagraph(doc_number[2].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[3].AddParagraph(doc_number[3].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[4].AddParagraph(doc_number[4].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[5].AddParagraph(doc_number[5].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[6].AddParagraph(doc_number[6].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph = row.Cells[7].AddParagraph(doc_number[7].ToString());
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            row = table.AddRow();
            row.Height = "2.5 pt";
            row.Cells[0].MergeRight = 4;
            row.Borders.Top.Visible = false;
















            #endregion

            #region  57

            field_1 = section.AddTextFrame();
            field_1.RelativeVertical = RelativeVertical.Page;
            field_1.Top = "764 pt";
            field_1.Left = "412.7 pt";
            table = field_1.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = TableBorder;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            column = table.AddColumn(Unit.FromPoint(68));
            column = table.AddColumn(Unit.FromPoint(65));
            row = table.AddRow();
            row.Height = "39.5 pt";
            row.Cells[0].Borders.Right.Visible = false;
            field_2 = row.Cells[0].AddTextFrame();
            field_3 = row.Cells[1].AddTextFrame();
            table2 = field_2.AddTable();
            table2.Rows.HeightRule = RowHeightRule.Exactly;
            column = table2.AddColumn(Unit.FromPoint(68));
            row = table2.AddRow();
            row.Height = "7 pt";
            paragraph = row.Cells[0].AddParagraph("57  ");
            paragraph.Format.Font.Size = 6;
            row = table2.AddRow();
            row.Height = "16.5 pt";
            row = table2.AddRow();
            row.Height = "5 pt";
            paragraph = row.Cells[0].AddParagraph("   ");
            paragraph.Format.Font.Size = 5;
            //row for data
            row = table2.AddRow();
            row.Height = "12 pt";
            paragraph = row.Cells[0].AddParagraph("672229");
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph.Format.Font.Size = 8;

            // next column of main table


            table3 = field_3.AddTable();
            column = table3.AddColumn(Unit.FromPoint(10.7));
            column = table3.AddColumn(Unit.FromPoint(10.7));
            column = table3.AddColumn(Unit.FromPoint(10.7));
            column = table3.AddColumn(Unit.FromPoint(10.7));
            column = table3.AddColumn(Unit.FromPoint(10.7));
            column = table3.AddColumn(Unit.FromPoint(10.7));
            table3.Rows.HeightRule = RowHeightRule.Exactly;
            row = table3.AddRow();
            row.Height = "10 pt";
            row.VerticalAlignment = VerticalAlignment.Center;
            row.Cells[0].MergeRight = 5;
            paragraph = row.Cells[0].AddParagraph("");
            paragraph.Format.Font.Size = 5;
            row = table3.AddRow();
            row.Height = "11 pt";
            row.Borders.Left.Style = BorderStyle.DashDot;
            row.Borders.Right.Style = BorderStyle.DashDot;
            row.Cells[5].Borders.Right.Visible = false;
            // cells 0-5 for data first row
            row.VerticalAlignment = VerticalAlignment.Center;

            row = table3.AddRow();
            row.Height = "6 pt";
            row.VerticalAlignment = VerticalAlignment.Center;
            row.Cells[0].MergeRight = 5;
            paragraph = row.Cells[0].AddParagraph("");
            paragraph.Format.Font.Size = 5;
            row.Borders.Top.Style = BorderStyle.Single;
            row.Borders.Top.Width = "0.5 pt";
            row = table3.AddRow();
            row.Height = "11 pt";
            row.Borders.Left.Style = BorderStyle.DashDot;
            row.Borders.Right.Style = BorderStyle.DashDot;
            row.Cells[5].Borders.Right.Visible = false;
            //cells 0-5 for data second row
            row.VerticalAlignment = VerticalAlignment.Center;







            #endregion


























































            /*
                       section = document.AddSection();
                 section.PageSetup.Orientation = Orientation.Landscape;

                 paragraph = section.AddParagraph("A4 landscape");
                 paragraph.Format.Font.Size = "1.5cm";

              */

            return document;
    }



    /// <summary>
    /// Creates the document from sample HelloMigraDoc.
    /// </summary>
    public static Document CreateSample2()
    {
      return Documents.CreateDocument();
    }
  }
}
