﻿using System;
using System.Diagnostics;
using System.Text;
using System.Data;
using MigraDoc.DocumentObjectModel;
using MigraDoc.DocumentObjectModel.Shapes;
using MigraDoc.DocumentObjectModel.Tables;


namespace DocumentViewer
{
    class gy3
    {

        public static Document createGy3 (DaoGy3 data)
        {

            Document document = new Document();
            Section section;
            Table table;
            Paragraph paragraph;

            TextFrame frame;
            FormattedText format;
            Column column;
            Row row;
            Row[] data_row = new Row[data.dt.Rows.Count];
            int index = 0;


            // define styles
            Style style = document.Styles["Normal"];
            style.ParagraphFormat.Font.Size = "7 pt";
            style = document.Styles.AddStyle("cells", "Normal");
            style.ParagraphFormat.Alignment = ParagraphAlignment.Center;
            style.ParagraphFormat.LineSpacingRule = LineSpacingRule.Single;
            style.ParagraphFormat.Font.Size = 6;
            



            section = document.AddSection();
            section.PageSetup.Orientation = Orientation.Landscape;
            section.PageSetup.TopMargin = "1 pt";
            section.PageSetup.LeftMargin = "1 pt";

            frame = section.AddTextFrame();
            frame.Top = "30 pt";
            frame.Left = "60 pt";
            frame.RelativeVertical = RelativeVertical.Page;
            paragraph = frame.AddParagraph("Станция   ");
            paragraph.AddText(data.Station);


            frame = section.AddTextFrame();
            frame.Top = "40 pt";
            frame.Left = "350 pt";
            frame.RelativeVertical = RelativeVertical.Page;
            frame.Width = "200 pt";
            frame.Height = "45 pt";
            paragraph = frame.AddParagraph("В Е Д О М О С Т Ь  №  ");
            paragraph.Format.Alignment = ParagraphAlignment.Center;
            paragraph.Format.LineSpacingRule = LineSpacingRule.Exactly;
            paragraph.Format.LineSpacing = " 12 pt";
            format =paragraph.AddFormattedText(data.doc_num);
            format.Font.Size = 9;
            format.Font.Bold = true;
            format.Font.Underline = Underline.Single;
            paragraph.AddLineBreak();
            paragraph.AddText("номерного учёта нагруженных вагонов");
            paragraph.AddLineBreak();
            paragraph.AddText("за отчётные сутки  ");
            format=paragraph.AddFormattedText(data.date);
            format.Font.Underline = Underline.Single;
            format.Font.Size = 9;
            format.Font.Bold = true;

            // главная таблица
            frame = section.AddTextFrame();
            frame.Top = "96 pt";
            frame.Left = "66 pt";
            table = frame.AddTable();
            table.Borders.Width = "1 pt";
            table.Borders.Color = Colors.Black;
            table.Rows.HeightRule = RowHeightRule.Exactly;
            table.Rows.VerticalAlignment = VerticalAlignment.Center;
            column = table.AddColumn(Unit.FromPoint(40));
            column = table.AddColumn(Unit.FromPoint(54));
            column = table.AddColumn(Unit.FromPoint(157));
            column = table.AddColumn(Unit.FromPoint(39));
            column = table.AddColumn(Unit.FromPoint(42));
            column = table.AddColumn(Unit.FromPoint(50));
            column = table.AddColumn(Unit.FromPoint(41));
            column = table.AddColumn(Unit.FromPoint(68));
            column = table.AddColumn(Unit.FromPoint(53));
            column = table.AddColumn(Unit.FromPoint(180));
            row = table.AddRow();
            row.Height = "11 pt";
            row.Cells[0].MergeDown = 1;
            row.Cells[1].MergeDown = 1;
            row.Cells[2].MergeDown = 1;
            row.Cells[3].MergeRight = 2;
            row.Cells[6].MergeDown = 1;
            row.Cells[7].MergeDown = 1;
            row.Cells[8].MergeDown = 1;
            row.Cells[9].MergeDown = 1;
           
            paragraph = row.Cells[0].AddParagraph("№   Отправки");
            paragraph.Style = "cells";
            paragraph = row.Cells[1].AddParagraph("Код станции назначения");
            paragraph.Style = "cells";
            paragraph = row.Cells[2].AddParagraph("Наименование груза");
            paragraph.Style = "cells";
            paragraph = row.Cells[3].AddParagraph("Номенклатура группы груза");
            paragraph.Style = "cells";

            paragraph = row.Cells[6].AddParagraph("Масса груза (кг)");
            paragraph.Style = "cells";
            paragraph = row.Cells[7].AddParagraph("№ вагона");
            paragraph.Style = "cells";
            paragraph = row.Cells[8].AddParagraph("Грузоподъем ность вагона");
            paragraph.Style = "cells";
            paragraph = row.Cells[9].AddParagraph("Отметки о вагонах, которые пренадлежат другим министерствам и ведомствам или арендованные, пустые, внутреннего передвижения и прочее");
            paragraph.Style = "cells";
            row = table.AddRow();
            row.Height = "55 pt";
            paragraph = row.Cells[3].AddParagraph("Шифр группы");
            paragraph.Style = "cells";
            paragraph = row.Cells[4].AddParagraph("Группа, позиция");
            paragraph.Style = "cells";
            paragraph = row.Cells[5].AddParagraph("порядковый номер группы в номенклатуре грузов");
            paragraph.Style = "cells";
            row = table.AddRow();
            row.Height = "11 pt";
            for (int i = 1; i < 11; i++)
            {
                paragraph = row.Cells[i - 1].AddParagraph(i.ToString());
                paragraph.Style = "cells";
            }
            
            foreach (DataRow row_table in data.dt.Rows )
            {
                data_row[index] = table.AddRow();
                data_row[index].HeightRule = RowHeightRule.AtLeast;
                data_row[index].Height = "15 pt";
                int j = 0;
                foreach(DataColumn dc in data.dt.Columns)
                {
                    paragraph = data_row[index].Cells[j].AddParagraph(row_table[dc].ToString());
                    paragraph.Style = "cells";
                    j++;
                    paragraph.AddText(data_row[index].Height.ToString());
                }
        
            }
            










            return document;
        }



    }


    


}
